@@ -1,6 +1,7 @@
 import click
 
 from hoss.commands.upload import upload
+from hoss.commands.download import download
 from hoss.commands.version import version
 
 CONTEXT_SETTINGS = dict(help_option_names=['-h', '--help'])
@@ -14,6 +15,7 @@ def cli():
 
 # Add commands from package
 cli.add_command(upload)
+cli.add_command(download)
 cli.add_command(version)
 
 
