@@ -4,7 +4,7 @@ import datetime
 
 from hoss.error import *
 from hoss.auth import AuthService
-from hoss.dataset import Dataset
+from hoss.dataset import Dataset, DeleteStatus
 from hoss.api import CoreAPI
 from hoss.objectstore import ObjectStore
 
@@ -97,10 +97,20 @@ class Namespace(CoreAPI):
             for perm in api_response["permissions"]
         }
 
+        # Because the zero value for golang representing a datetime does not have a decimal
+        # component, but when the time is actually set it does, we need to parse the `delete_on`
+        # value conditionally.
+        if "." in api_response['delete_on']:
+            delete_on = datetime.datetime.strptime(api_response['delete_on'], "%Y-%m-%dT%H:%M:%S.%fZ")
+        else:
+            delete_on = datetime.datetime.strptime(api_response['delete_on'], "%Y-%m-%dT%H:%M:%SZ")
+
         return Dataset(self,
                        api_response["name"],
                        api_response["description"],
                        datetime.datetime.strptime(api_response['created'], "%Y-%m-%dT%H:%M:%S.%fZ"),
+                       delete_on,
+                       DeleteStatus(api_response['delete_status']),
                        api_response['root_directory'],
                        api_response["owner"]["username"],
                        self.bucket,
@@ -142,7 +152,8 @@ class Namespace(CoreAPI):
         return self._populate_dataset(response)
 
     def delete_dataset(self, dataset_name: str) -> None:
-        """
+        """Mark a dataset for deletion. Depending on your server configuration, this may happen immediately
+        or after some fixed amount of time (e.g. 48hrs).
 
         Args:
             dataset_name: The name of the dataset to delete
@@ -152,4 +163,17 @@ class Namespace(CoreAPI):
         """
         self._request("DELETE", f"/namespace/{self.name}/dataset/{dataset_name}")
 
+    def restore_dataset(self, dataset_name: str) -> None:
+        """Restore a dataset that has been marked for delete, but is still in the `SCHEDULED` state.
+
+        Note: This is only available to users with the admin role.
+
+        Args:
+            dataset_name: The name of the dataset to "unmark" for delete
+
+        Returns:
+            None
+        """
+        self._request("PUT", f"/namespace/{self.name}/dataset/{dataset_name}/restore")
+
 
